package handler

import (
	"errors"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"fusenapi/server/shopping-cart-confirmation/internal/logic"
	"fusenapi/server/shopping-cart-confirmation/internal/svc"
	"fusenapi/server/shopping-cart-confirmation/internal/types"
)

func CartAddHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {

		var (
			// 定义错误变量
			err error
			// 定义用户信息变量
			userinfo *auth.UserInfo
		)
		// 解析JWT token,并对空用户进行判断
		claims, err := svcCtx.ParseJwtToken(r)
		// 如果解析JWT token出错,则返回未授权的JSON响应并记录错误消息
		if err != nil {
			httpx.OkJsonCtx(r.Context(), w, &basic.Response{
				Code:    401,            // 返回401状态码,表示未授权
				Message: "unauthorized", // 返回未授权信息
			})
			logx.Info("unauthorized:", err.Error()) // 记录错误日志
			return
		}

		if claims != nil {
			// 从token中获取对应的用户信息
			userinfo, err = auth.GetUserInfoFormMapClaims(claims)
			// 如果获取用户信息出错,则返回未授权的JSON响应并记录错误消息
			if err != nil {
				httpx.OkJsonCtx(r.Context(), w, &basic.Response{
					Code:    401,
					Message: "unauthorized",
				})
				logx.Info("unauthorized:", err.Error())
				return
			}
		} else {
			// 如果claims为nil,则认为用户身份为白板用户
			userinfo = &auth.UserInfo{UserId: 0, GuestId: 0}
		}

		var req types.CartAddReq
		// 如果端点有请求结构体，则使用httpx.Parse方法从HTTP请求体中解析请求数据
		if err := httpx.Parse(r, &req); err != nil {
			httpx.OkJsonCtx(r.Context(), w, &basic.Response{
				Code:    510,
				Message: "parameter error",
			})
			logx.Info(err)
			return
		}
		// 创建一个业务逻辑层实例
		l := logic.NewCartAddLogic(r.Context(), svcCtx)
		resp := l.CartAdd(&req, userinfo)
		// 如果响应不为nil，则使用httpx.OkJsonCtx方法返回JSON响应;
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
